import { __rest } from "tslib";
import * as React from 'react';
import { css } from '@patternfly/react-styles';
import '@patternfly/patternfly/patternfly-date-picker.css';
import styles from '@patternfly/react-styles/css/components/DatePicker/date-picker';
import buttonStyles from '@patternfly/react-styles/css/components/Button/button';
import { TextInput } from "@patternfly/react-core/dist/esm/components/TextInput/TextInput";
import { Popover, PopoverProps } from "@patternfly/react-core/dist/esm/components/Popover/Popover";
import { InputGroup } from "@patternfly/react-core/dist/esm/components/InputGroup/InputGroup";
import OutlinedCalendarAltIcon from "@patternfly/react-icons/dist/esm/icons/outlined-calendar-alt-icon";
import { CalendarMonth } from '../CalendarMonth';
const isValidDate = (date) => !isNaN(date.getTime());
export const DatePicker = (_a) => {
    var { className, locale = undefined, dateFormat = (date) => date.toISOString().substring(0, 10), dateParse = (val) => new Date(`${val}T00:00:00`), isDisabled = false, placeholder = 'yyyy-MM-dd', value: valueProp = '', 'aria-label': ariaLabel = 'Date picker', buttonAriaLabel = 'Toggle date picker', onChange = () => undefined, invalidFormatText = 'Could not parse date', helperText, appendTo, popoverProps, monthFormat, weekdayFormat, longWeekdayFormat, dayFormat, weekStart, validators = [] } = _a, props = __rest(_a, ["className", "locale", "dateFormat", "dateParse", "isDisabled", "placeholder", "value", 'aria-label', "buttonAriaLabel", "onChange", "invalidFormatText", "helperText", "appendTo", "popoverProps", "monthFormat", "weekdayFormat", "longWeekdayFormat", "dayFormat", "weekStart", "validators"]);
    const [value, setValue] = React.useState(valueProp);
    const [valueDate, setValueDate] = React.useState(dateParse(value));
    const [errorText, setErrorText] = React.useState('');
    const [popoverOpen, setPopoverOpen] = React.useState(false);
    const [selectOpen, setSelectOpen] = React.useState(false);
    const buttonRef = React.useRef();
    const onTextInput = (value) => {
        setValue(value);
        const newValueDate = dateParse(value);
        if (isValidDate(newValueDate)) {
            setValueDate(newValueDate);
            setErrorText(validators.map(validator => validator(newValueDate)).join('\n') || '');
            onChange(value, newValueDate);
        }
        else {
            setErrorText(invalidFormatText);
            onChange(value);
        }
    };
    const onDateClick = (newValueDate) => {
        const newValue = dateFormat(newValueDate);
        setValue(newValue);
        setValueDate(newValueDate);
        setErrorText(validators.map(validator => validator(newValueDate)).join('\n') || '');
        setPopoverOpen(false);
        onChange(newValue, newValueDate);
    };
    return (React.createElement("div", Object.assign({ className: css(styles.datePicker, className) }, props),
        React.createElement(Popover, Object.assign({ position: "bottom", bodyContent: React.createElement(CalendarMonth, { date: valueDate, onChange: onDateClick, locale: locale, 
                // Use truthy values of strings
                validators: validators.map(validator => (date) => !validator(date)), onSelectToggle: open => setSelectOpen(open), monthFormat: monthFormat, weekdayFormat: weekdayFormat, longWeekdayFormat: longWeekdayFormat, dayFormat: dayFormat, weekStart: weekStart }), showClose: false, isVisible: popoverOpen, shouldClose: (_1, _2, event) => {
                event = event;
                // Let the select menu close
                if (event.keyCode && event.keyCode === 27 && selectOpen) {
                    return false;
                }
                // Let our button handle toggling
                if (buttonRef.current && buttonRef.current.contains(event.target)) {
                    return false;
                }
                setPopoverOpen(false);
                return true;
            }, withFocusTrap: true, hasNoPadding: true, hasAutoWidth: true, appendTo: appendTo }, popoverProps),
            React.createElement(InputGroup, null,
                React.createElement(TextInput, { isDisabled: isDisabled, "aria-label": ariaLabel, placeholder: placeholder, validated: errorText ? 'error' : 'default', value: value, onChange: onTextInput }),
                React.createElement("button", { ref: buttonRef, className: css(buttonStyles.button, buttonStyles.modifiers.control), "aria-label": buttonAriaLabel, onClick: () => setPopoverOpen(!popoverOpen) },
                    React.createElement(OutlinedCalendarAltIcon, null)))),
        helperText && React.createElement("div", { className: styles.datePickerHelperText }, helperText),
        errorText && React.createElement("div", { className: css(styles.datePickerHelperText, styles.modifiers.error) }, errorText)));
};
DatePicker.displayName = 'DatePicker';
//# sourceMappingURL=DatePicker.js.map